@@ -6,7 +6,7 @@ from ..util import client,result_cache, config,oss_client
 from terminal import yellow,blue
 from ..const import CMD
 import re
-
+MOUNTS_PROTOCOLS = ['smb://','lustre://','nasplus://', 'nas://','oss://']
 
 def parse_id_arr(arr, type='jobs', needCheckGod=False):
     t=[]
@@ -104,7 +104,91 @@ def parse_cluster_cfg(s=None, checkCluster=True):
             return {'ClusterId': s, 'AutoCluster': {}}
 
 
+def trans_mount_dup(s):
+    if not s:
+        return None
+    arr = s.split(',')
+    mounts = []
+    m = {}
+    for item in arr:
+        item = item.strip()
 
+        # :::
+        if item.find(':::') != -1:
+            arr = item.split(':::')
+            k = arr[0]
+            v = arr[1]
+            w = arr[2] == 'true' if len(arr) == 3 else k.endswith('/')
+
+            if v in MOUNTS_PROTOCOLS:
+                (k,v) = (v,k)
+
+
+
+        elif item.startswith('oss://') or item.startswith('nas://'):
+
+            ind = item.rfind(':')
+
+            k = item[0:ind]
+            v = item[ind+1:]
+
+            if v=='true' or v=='false':
+                w = v=='true'
+                ind2 = k.rfind(':')
+                v = k[ind2 + 1:]
+                k = k[0:ind2]
+            else:
+                w = k.endswith('/')
+        else:
+            if ':oss://' in item:
+                ind = item.find(':oss://')
+                v = item[0:ind]
+                k = item[ind+1:]
+                w = k.endswith('/')
+            elif ':nas://' in item:
+                ind = item.find(':nas://')
+                v = item[0:ind]
+                k = item[ind + 1:]
+                w = k.endswith('/')
+
+            else:
+                raise Exception('Invalid mounts format')
+                #[k,v]=item.split(':',1)
+
+            if k.endswith(':true') or k.endswith(':false'):
+                w = k.endswith(':true')
+                k = k[:-6]
+
+
+        if len(v)==1 and str.isalpha(v):
+            v = v + ':'
+        m[k+'^^^'+v] = {'Source':k, 'Destination': v, 'WriteSupport': w}
+
+    for (k2,v2) in m.items():
+        mounts.append(v2)
+    return mounts
+
+
+def trans_deps(deps):
+    # A->b,c;d->e,f
+    parts = deps.strip(';').split(';')
+    m = {}
+    for part in parts:
+      if '->' in part:
+        arr = part.split('->')
+        count = len(arr)
+        for i in range(count-1):
+            k = arr[i]
+            v = arr[i+1]
+
+            ks = [x.strip() for x in k.split(',')]
+            vs = [x.strip() for x in v.split(',')]
+            for kn in ks:
+                if not m.get(kn):
+                    m[kn]=[]
+                m[kn] += vs
+            #m[k] = [x.strip() for x in v.split(',')]
+    return m
 
 def trans_mount(s):
     if not s:
